@@ -15,13 +15,13 @@ class Base(dict):
     def _get_link(self, name):
         """Return a link by its name."""
         try:
-            return self['_links'][name]['href']
+            return self["_links"][name]["href"]
         except (KeyError, TypeError):
             return None
 
     @classmethod
     def get_object_name(cls):
-        return '{name}s'.format(name=cls.__name__.lower())
+        return "{name}s".format(name=cls.__name__.lower())
 
     @classmethod
     def get_resource_class(cls, client):
