@@ -10,7 +10,7 @@ class List(Base):
 
     def __len__(self):
         """Return the count field."""
-        return int(self['count'])
+        return int(self["count"])
 
     def __iter__(self):
         """Implement iterator interface."""
@@ -24,7 +24,7 @@ class List(Base):
         else:
             self.current += 1
         try:
-            item = self['_embedded'][self.object_type.get_object_name()][self.current]
+            item = self["_embedded"][self.object_type.get_object_name()][self.current]
             return self.object_type(item, self.client)
         except IndexError:
             self.current = None
@@ -34,28 +34,28 @@ class List(Base):
 
     @property
     def count(self):
-        if 'count' not in self:
+        if "count" not in self:
             return None
-        return int(self['count'])
+        return int(self["count"])
 
     def has_next(self):
         """Return True if the list contains an url for the next set"""
-        return self._get_link('next') is not None
+        return self._get_link("next") is not None
 
     def has_previous(self):
         """Return True if the list contains an url for the previous set"""
-        return self._get_link('previous') is not None
+        return self._get_link("previous") is not None
 
     def get_next(self):
         """Return the next set of objects in a list"""
-        url = self._get_link('next')
+        url = self._get_link("next")
         resource = self.object_type.get_resource_class(self.client)
         resp = resource.perform_api_call(resource.REST_READ, url)
         return List(resp, self.object_type, self.client)
 
     def get_previous(self):
         """Return the previous set of objects in a list"""
-        url = self._get_link('previous')
+        url = self._get_link("previous")
         resource = self.object_type.get_resource_class(self.client)
         resp = resource.perform_api_call(resource.REST_READ, url)
         return List(resp, self.object_type, self.client)
