@@ -4,7 +4,7 @@ from .base import Base
 
 
 class Chargebacks(Base):
-    RESOURCE_ID_PREFIX = 'chb_'
+    RESOURCE_ID_PREFIX = "chb_"
 
     def get_resource_object(self, result):
         return Chargeback(result)
@@ -14,6 +14,7 @@ class Chargebacks(Base):
         if not chargeback_id or not chargeback_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
                 "Invalid chargeback ID: '{id}'. A chargeback ID should start with '{prefix}'.".format(
-                    id=chargeback_id, prefix=self.RESOURCE_ID_PREFIX)
+                    id=chargeback_id, prefix=self.RESOURCE_ID_PREFIX
+                )
             )
         return super().get(chargeback_id, **params)
