@@ -4,7 +4,7 @@ from .base import Base
 
 
 class CustomerMandates(Base):
-    RESOURCE_ID_PREFIX = 'mdt_'
+    RESOURCE_ID_PREFIX = "mdt_"
     customer_id = None
 
     def get_resource_object(self, result):
@@ -14,12 +14,13 @@ class CustomerMandates(Base):
         if not mandate_id or not mandate_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
                 "Invalid mandate ID: '{id}'. A mandate ID should start with '{prefix}'.".format(
-                    id=mandate_id, prefix=self.RESOURCE_ID_PREFIX)
+                    id=mandate_id, prefix=self.RESOURCE_ID_PREFIX
+                )
             )
         return super().get(mandate_id, **params)
 
     def get_resource_name(self):
-        return 'customers/{id}/mandates'.format(id=self.customer_id)
+        return "customers/{id}/mandates".format(id=self.customer_id)
 
     def with_parent_id(self, customer_id):
         self.customer_id = customer_id
