@@ -4,7 +4,7 @@ from .base import Base
 
 
 class Invoices(Base):
-    RESOURCE_ID_PREFIX = 'inv_'
+    RESOURCE_ID_PREFIX = "inv_"
 
     def get_resource_object(self, result):
         return Invoice(result, self.client)
@@ -13,6 +13,7 @@ class Invoices(Base):
         if not invoice_id or not invoice_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
                 "Invalid invoice ID: '{id}'. A invoice ID should start with '{prefix}'.".format(
-                    id=invoice_id, prefix=self.RESOURCE_ID_PREFIX)
+                    id=invoice_id, prefix=self.RESOURCE_ID_PREFIX
+                )
             )
         return super().get(invoice_id, **params)
