@@ -5,7 +5,7 @@ class PaymentChargebacks(Chargebacks):
     payment_id = None
 
     def get_resource_name(self):
-        return 'payments/{id}/chargebacks'.format(id=self.payment_id)
+        return "payments/{id}/chargebacks".format(id=self.payment_id)
 
     def with_parent_id(self, payment_id):
         self.payment_id = payment_id
